==> jc-1.4.0.tar.gz: java/lang/RuntimeException.h <==
// public class java.lang.RuntimeException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_lang_RuntimeException_H_
#define _JC_java_lang_RuntimeException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_java_lang_RuntimeException$sub_refs	_jc_java_lang_RuntimeException$sub_refs;
typedef struct _jc_java_lang_RuntimeException$sub_nonrefs	_jc_java_lang_RuntimeException$sub_nonrefs;
typedef struct _jc_java_lang_RuntimeException$refs	_jc_java_lang_RuntimeException$refs;
typedef struct _jc_java_lang_RuntimeException$nonrefs	_jc_java_lang_RuntimeException$nonrefs;
typedef struct _jc_java_lang_RuntimeException$object	_jc_java_lang_RuntimeException$object;

typedef struct _jc_java_lang_RuntimeException$fields_struct	_jc_java_lang_RuntimeException$fields_struct;
typedef const struct _jc_java_lang_RuntimeException$vmethods	_jc_java_lang_RuntimeException$vmethods;
typedef const struct _jc_java_lang_RuntimeException$vtable	_jc_java_lang_RuntimeException$vtable;
typedef const struct _jc_java_lang_RuntimeException$vtype	_jc_java_lang_RuntimeException$vtype;

// Class fields structure
struct _jc_java_lang_RuntimeException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_RuntimeException$fields_struct _jc_java_lang_RuntimeException$class_fields;

// Constructors
extern void _jc_java_lang_RuntimeException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_RuntimeException$object *);
extern void _jc_java_lang_RuntimeException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_RuntimeException$object *, struct _jc_java_lang_String$object *);
extern void _jc_java_lang_RuntimeException$method$_init$e87bb26efeed946b(_jc_env *, struct _jc_java_lang_RuntimeException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Throwable$object *);
extern void _jc_java_lang_RuntimeException$method$_init$8b52a141d2a0e2bc(_jc_env *, struct _jc_java_lang_RuntimeException$object *, struct _jc_java_lang_Throwable$object *);

// Virtual methods structure
struct _jc_java_lang_RuntimeException$vmethods {
};

// Vtable
struct _jc_java_lang_RuntimeException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
};

// Vtype
struct _jc_java_lang_RuntimeException$vtype {
	_jc_type			type;
	_jc_java_lang_RuntimeException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_RuntimeException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_RuntimeException$refs {
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_RuntimeException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_RuntimeException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
};

// Object instance structure
struct _jc_java_lang_RuntimeException$object {
	_jc_java_lang_RuntimeException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_RuntimeException$vtype	*vtype;
	_jc_java_lang_RuntimeException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_RuntimeException$vtype _jc_java_lang_RuntimeException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_RuntimeException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_RuntimeException$class_object;

#endif	/* _JC_java_lang_RuntimeException_H_ */

==> jc-1.4.6.tar.gz: java/lang/RuntimeException.h <==
// public class java.lang.RuntimeException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_lang_RuntimeException_H_
#define _JC_java_lang_RuntimeException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_java_lang_RuntimeException$sub_refs	_jc_java_lang_RuntimeException$sub_refs;
typedef struct _jc_java_lang_RuntimeException$sub_nonrefs	_jc_java_lang_RuntimeException$sub_nonrefs;
typedef struct _jc_java_lang_RuntimeException$refs	_jc_java_lang_RuntimeException$refs;
typedef struct _jc_java_lang_RuntimeException$nonrefs	_jc_java_lang_RuntimeException$nonrefs;
typedef struct _jc_java_lang_RuntimeException$object	_jc_java_lang_RuntimeException$object;

typedef struct _jc_java_lang_RuntimeException$fields_struct	_jc_java_lang_RuntimeException$fields_struct;
typedef const struct _jc_java_lang_RuntimeException$vmethods	_jc_java_lang_RuntimeException$vmethods;
typedef const struct _jc_java_lang_RuntimeException$vtable	_jc_java_lang_RuntimeException$vtable;
typedef const struct _jc_java_lang_RuntimeException$vtype	_jc_java_lang_RuntimeException$vtype;

// Class fields structure
struct _jc_java_lang_RuntimeException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_RuntimeException$fields_struct _jc_java_lang_RuntimeException$class_fields;

// Constructors
extern void _jc_java_lang_RuntimeException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_RuntimeException$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_RuntimeException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_RuntimeException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_RuntimeException$method$_init$e87bb26efeed946b(_jc_env *, struct _jc_java_lang_RuntimeException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Throwable$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_RuntimeException$method$_init$8b52a141d2a0e2bc(_jc_env *, struct _jc_java_lang_RuntimeException$object *, struct _jc_java_lang_Throwable$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_RuntimeException$vmethods {
};

// Vtable
struct _jc_java_lang_RuntimeException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
};

// Vtype
struct _jc_java_lang_RuntimeException$vtype {
	_jc_type			type;
	_jc_java_lang_RuntimeException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_RuntimeException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_RuntimeException$refs {
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_RuntimeException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_RuntimeException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
};

// Object instance structure
struct _jc_java_lang_RuntimeException$object {
	_jc_java_lang_RuntimeException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_RuntimeException$vtype	*vtype;
	_jc_java_lang_RuntimeException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_RuntimeException$vtype _jc_java_lang_RuntimeException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_RuntimeException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_RuntimeException$class_object;

#endif	/* _JC_java_lang_RuntimeException_H_ */
